==> deltaspike-1.9.6-source-release.zip: deltaspike-1.9.6/deltaspike/modules/data/impl/src/main/java/org/apache/deltaspike/data/impl/util/jpa/PersistenceUnitUtilDelegateFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.deltaspike.data.impl.util.jpa;

import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;
import javax.persistence.PersistenceUnitUtil;

public class PersistenceUnitUtilDelegateFactory
{
    private PersistenceUnitUtilDelegateFactory()
    {
    }

    public static PersistenceUnitUtil get(EntityManager entityManager)
    {
        final EntityManagerFactory entityManagerFactory = entityManager.getEntityManagerFactory();
        final String vendorName = (String) entityManagerFactory.getProperties().get("VendorName");
        if (vendorName != null && "openjpa".equalsIgnoreCase(vendorName))
        {
            return new OpenJpaPersistenceUnitUtilDelegate(entityManager);
        }
        return entityManagerFactory.getPersistenceUnitUtil();
    }
}

==> deltaspike-2.0.1-source-release.zip: deltaspike-2.0.1/deltaspike/modules/data/impl/src/main/java/org/apache/deltaspike/data/impl/util/jpa/PersistenceUnitUtilDelegateFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.deltaspike.data.impl.util.jpa;

import jakarta.persistence.EntityManager;
import jakarta.persistence.EntityManagerFactory;
import jakarta.persistence.PersistenceUnitUtil;

public class PersistenceUnitUtilDelegateFactory
{
    private PersistenceUnitUtilDelegateFactory()
    {
    }

    public static PersistenceUnitUtil get(EntityManager entityManager)
    {
        final EntityManagerFactory entityManagerFactory = entityManager.getEntityManagerFactory();
        final String vendorName = (String) entityManagerFactory.getProperties().get("VendorName");
        if (vendorName != null && "openjpa".equalsIgnoreCase(vendorName))
        {
            return new OpenJpaPersistenceUnitUtilDelegate(entityManager);
        }
        return entityManagerFactory.getPersistenceUnitUtil();
    }
}
